# GraphQL Schema

This directory contains the latest GraphQL schema for the W&B API.

## To update the schema:
1. Update the commit hash in `./core/api/graphql/schemas/commit.hash.txt`
2. Re-run `./core/api/graphql/generate-graphql.sh`
